@@ -527,7 +527,8 @@ static int visir_old_spc_obs(cpl_frameset            * framelist,
                          "photometric calibration", rawtag);
 
         if (visir_spc_phot_sensit(rawframes, &spc_config, plist, star_cat,
-                                  &weight2d, qclist, spc_table, dit_key)) {
+                                  &weight2d, qclist, spc_table, resol,
+                                  dit_key)) {
             if (!(input_mode & IS_PHOT)) {
                 irplib_error_recover(prestate, "The frame set contains "
                                      "observation frame(s) (%s) together with "
