@@ -140,8 +140,6 @@
 #define VISIR_CALIB_FLAT                    "FLAT"
 #define VISIR_CALIB_BPM                     "BPM"
 #define VISIR_CALIB_STATIC_MASK             "STATIC_MASK"
-#define VISIR_CALIB_STATIC_MASK_SPC         "STATIC_MASK_SPECTRUM"
-#define VISIR_CALIB_STATIC_MASK_IMG         "STATIC_MASK_IMAGE"
 #define VISIR_CALIB_STDSTAR_IMG             "IMG_STD_CATALOG"             
 #define VISIR_CALIB_STDSTAR_SPC             "SPEC_STD_CATALOG"             
 #define VISIR_CALIB_LINES_SPC               "SPEC_CAL_LINES"
